@@ -188,10 +188,14 @@ nice_component_remove_socket (NiceAgent *agent, NiceComponent *cmp,
     }
 
     refresh_prune_candidate (agent, candidate);
-    if (candidate->sockptr != nsocket && stream) {
-      discovery_prune_socket (agent, candidate->sockptr);
+    discovery_prune_socket (agent, candidate->sockptr);
+    if (stream) {
       conn_check_prune_socket (agent, stream, cmp,
           candidate->sockptr);
+    }
+
+    /* Keep nsocket alive since it's used in the loop. */
+    if (candidate->sockptr != nsocket) {
       nice_component_detach_socket (cmp, candidate->sockptr);
     }
     agent_remove_local_candidate (agent, candidate);
@@ -201,16 +205,29 @@ nice_component_remove_socket (NiceAgent *agent, NiceComponent *cmp,
     i = next;
   }
 
-  discovery_prune_socket (agent, nsocket);
-  if (stream)
-    conn_check_prune_socket (agent, stream, cmp, nsocket);
   nice_component_detach_socket (cmp, nsocket);
 }
 
+static gboolean
+on_candidate_refreshes_pruned (NiceAgent *agent, NiceCandidate *candidate)
+{
+  NiceComponent *component;
+
+  if (agent_find_component (agent, candidate->stream_id,
+      candidate->component_id, NULL, &component)) {
+    nice_component_detach_socket (component, candidate->sockptr);
+  }
+
+  nice_candidate_free (candidate);
+
+  return G_SOURCE_REMOVE;
+}
+
 void
 nice_component_clean_turn_servers (NiceAgent *agent, NiceComponent *cmp)
 {
   GSList *i;
+  GSList *relay_candidates = NULL;
   NiceStream *stream;
 
   stream = agent_find_stream (agent, cmp->stream_id);
@@ -238,13 +255,7 @@ nice_component_clean_turn_servers (NiceAgent *agent, NiceComponent *cmp)
      */
     if (candidate == cmp->selected_pair.local) {
       if (cmp->turn_candidate) {
-        refresh_prune_candidate (agent, cmp->turn_candidate);
-        discovery_prune_socket (agent, cmp->turn_candidate->sockptr);
-        if (stream)
-          conn_check_prune_socket (agent, stream, cmp,
-              cmp->turn_candidate->sockptr);
-        nice_component_detach_socket (cmp, cmp->turn_candidate->sockptr);
-	nice_candidate_free (cmp->turn_candidate);
+        relay_candidates = g_slist_append(relay_candidates, cmp->turn_candidate);
       }
       /* Bring the priority down to 0, so that it will be replaced
        * on the new run.
@@ -252,18 +263,24 @@ nice_component_clean_turn_servers (NiceAgent *agent, NiceComponent *cmp)
       cmp->selected_pair.priority = 0;
       cmp->turn_candidate = candidate;
     } else {
-      refresh_prune_candidate (agent, candidate);
-      discovery_prune_socket (agent, candidate->sockptr);
-      if (stream)
-        conn_check_prune_socket (agent, stream, cmp,
-            candidate->sockptr);
-      nice_component_detach_socket (cmp, candidate->sockptr);
       agent_remove_local_candidate (agent, candidate);
-      nice_candidate_free (candidate);
+      relay_candidates = g_slist_append(relay_candidates, candidate);
     }
     cmp->local_candidates = g_slist_delete_link (cmp->local_candidates, i);
     i = next;
   }
+
+  for (i = relay_candidates; i; i = i->next) {
+    NiceCandidate * candidate = i->data;
+
+    discovery_prune_socket (agent, candidate->sockptr);
+    if (stream) {
+      conn_check_prune_socket (agent, stream, cmp, candidate->sockptr);
+    }
+
+    refresh_prune_candidate_async (agent, candidate,
+        (NiceTimeoutLockedCallback) on_candidate_refreshes_pruned);
+  }
 }
 
 static void
@@ -442,14 +459,13 @@ nice_component_update_selected_pair (NiceAgent *agent, NiceComponent *component,
 
   if (component->selected_pair.local &&
       component->selected_pair.local == component->turn_candidate) {
-    refresh_prune_candidate (agent, component->turn_candidate);
     discovery_prune_socket (agent,
         component->turn_candidate->sockptr);
     if (stream)
       conn_check_prune_socket (agent, stream, component,
           component->turn_candidate->sockptr);
-    nice_component_detach_socket (component, component->turn_candidate->sockptr);
-    nice_candidate_free (component->turn_candidate);
+    refresh_prune_candidate_async (agent, component->turn_candidate,
+        (NiceTimeoutLockedCallback) on_candidate_refreshes_pruned);
     component->turn_candidate = NULL;
   }
 
