@@ -102,9 +102,6 @@ main(int argc, char *argv[])
     g_debug("Using stun server '[%s]:%u'\n", stun_addr, stun_port);
   }
 
-#if !GLIB_CHECK_VERSION(2, 36, 0)
-  g_type_init();
-#endif
   g_networking_init();
 
   gloop = g_main_loop_new(NULL, FALSE);
@@ -132,7 +129,7 @@ example_thread(void *data)
   int rval;
 
 #ifdef G_OS_WIN32
-  io_stdin = g_io_channel_win32_new(_fileno(stdin));
+  io_stdin = g_io_channel_win32_new_fd(_fileno(stdin));
 #else
   io_stdin = g_io_channel_unix_new(fileno(stdin));
 #endif
