@@ -265,6 +265,14 @@ nice_socket_set_writable_callback (NiceSocket *sock,
     sock->set_writable_callback (sock, callback, user_data);
 }
 
+gboolean
+nice_socket_is_based_on (NiceSocket *sock, NiceSocket *other)
+{
+  if (sock->is_based_on)
+    return sock->is_based_on (sock, other);
+  return (sock == other);
+}
+
 void
 nice_socket_free (NiceSocket *sock)
 {
@@ -332,7 +340,7 @@ nice_socket_queue_send (GQueue *send_queue, const NiceAddress *to,
 void nice_socket_queue_send_with_callback (GQueue *send_queue,
     const NiceOutputMessage *message, gsize message_offset, gsize message_len,
     gboolean head, GSocket *gsock, GSource **io_source, GMainContext *context,
-    GSourceFunc cb, gpointer user_data)
+    GSocketSourceFunc cb, gpointer user_data)
 {
   NiceSocketQueuedSend *tbs;
   guint j;
@@ -352,7 +360,7 @@ void nice_socket_queue_send_with_callback (GQueue *send_queue,
 
   if (io_source && gsock && context && cb && *io_source == NULL) {
     *io_source = g_socket_create_source(gsock, G_IO_OUT, NULL);
-    g_source_set_callback (*io_source, (GSourceFunc) cb, user_data, NULL);
+    g_source_set_callback (*io_source, (GSourceFunc) G_CALLBACK (cb), user_data, NULL);
     g_source_attach (*io_source, context);
   }
 
@@ -442,6 +450,6 @@ gboolean nice_socket_flush_send_queue_to_socket (GSocket *gsock,
 void
 nice_socket_free_send_queue (GQueue *send_queue)
 {
-  g_queue_foreach (send_queue, (GFunc) nice_socket_free_queued_send, NULL);
-  g_queue_clear (send_queue);
+  g_list_free_full (send_queue->head, (GDestroyNotify) nice_socket_free_queued_send);
+  g_queue_init (send_queue);
 }
