@@ -50,6 +50,7 @@
 #include <fcntl.h>
 
 #include "udp-bsd.h"
+#include "agent-priv.h"
 
 #ifndef G_OS_WIN32
 #include <unistd.h>
@@ -61,10 +62,18 @@ static gint socket_recv_messages (NiceSocket *sock,
     NiceInputMessage *recv_messages, guint n_recv_messages);
 static gint socket_send_messages (NiceSocket *sock, const NiceAddress *to,
     const NiceOutputMessage *messages, guint n_messages);
+static gint socket_send_messages_reliable (NiceSocket *sock,
+    const NiceAddress *to, const NiceOutputMessage *messages, guint n_messages);
 static gboolean socket_is_reliable (NiceSocket *sock);
+static gboolean socket_can_send (NiceSocket *sock, NiceAddress *addr);
+static void socket_set_writable_callback (NiceSocket *sock,
+    NiceSocketWritableCb callback, gpointer user_data);
 
 struct UdpBsdSocketPrivate
 {
+  GMutex mutex;
+
+  /* protected by mutex */
   NiceAddress niceaddr;
   GSocketAddress *gaddr;
 };
@@ -141,12 +150,18 @@ nice_udp_bsd_socket_new (NiceAddress *addr)
   priv = sock->priv = g_slice_new0 (struct UdpBsdSocketPrivate);
   nice_address_init (&priv->niceaddr);
 
+  sock->type = NICE_SOCKET_TYPE_UDP_BSD;
   sock->fileno = gsock;
   sock->send_messages = socket_send_messages;
+  sock->send_messages_reliable = socket_send_messages_reliable;
   sock->recv_messages = socket_recv_messages;
   sock->is_reliable = socket_is_reliable;
+  sock->can_send = socket_can_send;
+  sock->set_writable_callback = socket_set_writable_callback;
   sock->close = socket_close;
 
+  g_mutex_init (&priv->mutex);
+
   return sock;
 }
 
@@ -155,8 +170,8 @@ socket_close (NiceSocket *sock)
 {
   struct UdpBsdSocketPrivate *priv = sock->priv;
 
-  if (priv->gaddr)
-    g_object_unref (priv->gaddr);
+  g_clear_object (&priv->gaddr);
+  g_mutex_clear (&priv->mutex);
   g_slice_free (struct UdpBsdSocketPrivate, sock->priv);
   sock->priv = NULL;
 
@@ -174,6 +189,9 @@ socket_recv_messages (NiceSocket *sock,
   guint i;
   gboolean error = FALSE;
 
+  /* Make sure socket has not been freed: */
+  g_assert (sock->priv != NULL);
+
   /* Read messages into recv_messages until one fails or would block, or we
    * reach the end. */
   for (i = 0; i < n_recv_messages; i++) {
@@ -188,17 +206,22 @@ socket_recv_messages (NiceSocket *sock,
         recv_message->buffers, recv_message->n_buffers, NULL, NULL,
         &flags, NULL, &gerr);
 
-    recv_message->length = MAX (recvd, 0);
-
     if (recvd < 0) {
-      if (g_error_matches (gerr, G_IO_ERROR, G_IO_ERROR_WOULD_BLOCK))
+      /* Handle ECONNRESET here as if it were EWOULDBLOCK; see
+       * https://phabricator.freedesktop.org/T121 */
+      if (g_error_matches (gerr, G_IO_ERROR, G_IO_ERROR_WOULD_BLOCK) ||
+          g_error_matches (gerr, G_IO_ERROR, G_IO_ERROR_CONNECTION_CLOSED))
         recvd = 0;
+      else if (g_error_matches (gerr, G_IO_ERROR, G_IO_ERROR_MESSAGE_TOO_LARGE))
+        recvd = input_message_get_size (recv_message);
       else
         error = TRUE;
 
       g_error_free (gerr);
     }
 
+    recv_message->length = MAX (recvd, 0);
+
     if (recvd > 0 && recv_message->from != NULL && gaddr != NULL) {
       union {
         struct sockaddr_storage storage;
@@ -231,34 +254,50 @@ socket_send_message (NiceSocket *sock, const NiceAddress *to,
   struct UdpBsdSocketPrivate *priv = sock->priv;
   GError *child_error = NULL;
   gssize len;
+  GSocketAddress *gaddr = NULL;
 
+  /* Make sure socket has not been freed: */
+  g_assert (sock->priv != NULL);
+
+  g_mutex_lock (&priv->mutex);
   if (!nice_address_is_valid (&priv->niceaddr) ||
       !nice_address_equal (&priv->niceaddr, to)) {
     union {
       struct sockaddr_storage storage;
       struct sockaddr addr;
     } sa;
-    GSocketAddress *gaddr;
 
-    if (priv->gaddr)
-      g_object_unref (priv->gaddr);
+    g_clear_object (&priv->gaddr);
 
     nice_address_copy_to_sockaddr (to, &sa.addr);
     gaddr = g_socket_address_new_from_native (&sa.addr, sizeof(sa));
-    priv->gaddr = gaddr;
+    if (gaddr)
+      priv->gaddr = g_object_ref (gaddr);
 
-    if (gaddr == NULL)
+    if (gaddr == NULL) {
+      g_mutex_unlock (&priv->mutex);
       return -1;
+    }
 
     priv->niceaddr = *to;
+  } else {
+    if (priv->gaddr)
+      gaddr = g_object_ref (priv->gaddr);
   }
+  g_mutex_unlock (&priv->mutex);
 
-  len = g_socket_send_message (sock->fileno, priv->gaddr, message->buffers,
+  len = g_socket_send_message (sock->fileno, gaddr, message->buffers,
       message->n_buffers, NULL, 0, G_SOCKET_MSG_NONE, NULL, &child_error);
 
+  g_clear_object (&gaddr);
+
   if (len < 0) {
-    if (g_error_matches (child_error, G_IO_ERROR, G_IO_ERROR_WOULD_BLOCK))
+    if (g_error_matches (child_error, G_IO_ERROR, G_IO_ERROR_WOULD_BLOCK)) {
       len = 0;
+    } else {
+      nice_debug_verbose ("%s: udp-bsd socket %p: error: %s", G_STRFUNC, sock,
+          child_error->message);
+    }
 
     g_error_free (child_error);
   }
@@ -272,6 +311,9 @@ socket_send_messages (NiceSocket *sock, const NiceAddress *to,
 {
   guint i;
 
+  /* Make sure socket has not been freed: */
+  g_assert (sock->priv != NULL);
+
   for (i = 0; i < n_messages; i++) {
     const NiceOutputMessage *message = &messages[i];
     gssize len;
@@ -280,6 +322,8 @@ socket_send_messages (NiceSocket *sock, const NiceAddress *to,
 
     if (len < 0) {
       /* Error. */
+      if (i > 0)
+        break;
       return len;
     } else if (len == 0) {
       /* EWOULDBLOCK. */
@@ -290,9 +334,28 @@ socket_send_messages (NiceSocket *sock, const NiceAddress *to,
   return i;
 }
 
+static gint
+socket_send_messages_reliable (NiceSocket *sock, const NiceAddress *to,
+    const NiceOutputMessage *messages, guint n_messages)
+{
+  return -1;
+}
+
 static gboolean
 socket_is_reliable (NiceSocket *sock)
 {
   return FALSE;
 }
 
+static gboolean
+socket_can_send (NiceSocket *sock, NiceAddress *addr)
+{
+  return TRUE;
+}
+
+static void
+socket_set_writable_callback (NiceSocket *sock,
+    NiceSocketWritableCb callback, gpointer user_data)
+{
+}
+
