@@ -60,9 +60,15 @@
 #include <netdb.h>
 #include <netinet/in.h>
 
-#include <unistd.h>
+#ifdef HAVE_UNISTD_H
+# include <unistd.h>
+#else
+# define close(fd) _close(fd)
+#endif
+
 #include <errno.h>
 #include <limits.h>
+#include <stdio.h>
 
 #ifndef SOL_IP
 # define SOL_IP IPPROTO_IP
@@ -100,13 +106,12 @@ int listen_socket (int fam, int type, int proto, unsigned int port)
     struct sockaddr_in6 in6;
     struct sockaddr_storage storage;
   } addr;
+
   if (fd == -1)
   {
     perror ("Error opening IP port");
     return -1;
   }
-  if (fd < 3)
-    goto error;
 
   memset (&addr, 0, sizeof (addr));
   addr.storage.ss_family = fam;
@@ -131,7 +136,7 @@ int listen_socket (int fam, int type, int proto, unsigned int port)
       assert (0);  /* should never be reached */
   }
 
-  if (bind (fd, &addr.addr, sizeof (struct sockaddr)))
+  if (bind (fd, &addr.addr, sizeof (struct sockaddr_storage)))
   {
     perror ("Error opening IP port");
     goto error;
@@ -188,7 +193,7 @@ static int dgram_process (int sock, StunAgent *oldagent, StunAgent *newagent)
   StunValidationStatus validation;
   StunAgent *agent = NULL;
 
-  addr_len = sizeof (struct sockaddr_in);
+  addr_len = sizeof (struct sockaddr_storage);
   len = recvfrom (sock, buf, sizeof(buf), 0, &addr.addr, &addr_len);
   if (len == (size_t)-1)
     return -1;
@@ -281,29 +286,31 @@ int main (int argc, char *argv[])
 {
   int family = AF_INET;
   unsigned port = IPPORT_STUN;
+  int i;
 
-  for (;;)
+  for (i = 1; i < argc; ++i)
   {
-    int c = getopt (argc, argv, "46");
-    if (c == EOF)
-      break;
+    const char *arg = argv[i];
 
-    switch (c)
+    if (strcmp (arg, "-4") == 0)
     {
-      default:
-      case '4':
-        family = AF_INET;
-        break;
-
-      case '6':
-        family = AF_INET6;
-        break;
+      family = AF_INET;
+    }
+    else if (strcmp (arg, "-6") == 0)
+    {
+      family = AF_INET6;
+    }
+    else if (arg[0] < '0' || arg[0] > '9')
+    {
+      fprintf (stderr, "Unexpected command line argument '%s'", arg);
+    }
+    else
+    {
+      port = atoi (arg);
+      break;
     }
   }
 
-  if (optind < argc)
-    port = atoi (argv[optind++]);
-
   signal (SIGINT, exit_handler);
   signal (SIGTERM, exit_handler);
   return run (family, IPPROTO_UDP, port) ? EXIT_FAILURE : EXIT_SUCCESS;
