@@ -42,6 +42,8 @@
 
 #include "iostream.h"
 
+#include "test-io-stream-common.h"
+
 static void
 test_invalid_stream (NiceAddress *addr)
 {
@@ -49,6 +51,7 @@ test_invalid_stream (NiceAddress *addr)
   GIOStream *io_stream;
 
   agent = nice_agent_new_reliable (NULL, NICE_COMPATIBILITY_RFC5245);
+  g_object_set (G_OBJECT (agent), "upnp", FALSE, NULL);
   nice_agent_add_local_address (agent, addr);
 
   /* Try building an I/O stream for an invalid stream. All its operations should
@@ -69,6 +72,7 @@ test_io_stream_properties (NiceAddress *addr)
   GOutputStream *output_stream;
 
   agent = nice_agent_new_reliable (NULL, NICE_COMPATIBILITY_RFC5245);
+  g_object_set (G_OBJECT (agent), "upnp", FALSE, NULL);
   nice_agent_add_local_address (agent, addr);
 
   stream_id = nice_agent_add_stream (agent, 1);
@@ -125,6 +129,7 @@ test_pollable_properties (NiceAddress *addr)
   GSource *stream_source;
 
   agent = nice_agent_new_reliable (NULL, NICE_COMPATIBILITY_RFC5245);
+  g_object_set (G_OBJECT (agent), "upnp", FALSE, NULL);
   nice_agent_add_local_address (agent, addr);
 
   /* Add a stream. */
@@ -251,7 +256,7 @@ check_pollable_source_cancellation (GSource *pollable_source,
   main_loop = g_main_loop_new (main_context, FALSE);
 
   /* Set up the pollable source. */
-  g_source_set_callback (pollable_source, (GSourceFunc) source_cancelled_cb,
+  g_source_set_callback (pollable_source, G_SOURCE_FUNC (source_cancelled_cb),
       main_loop, NULL);
   g_source_attach (pollable_source, main_context);
 
@@ -295,6 +300,7 @@ test_pollable_cancellation (NiceAddress *addr)
   GCancellable *cancellable;
 
   agent = nice_agent_new_reliable (NULL, NICE_COMPATIBILITY_RFC5245);
+  g_object_set (G_OBJECT (agent), "upnp", FALSE, NULL);
   nice_agent_add_local_address (agent, addr);
 
   /* Add a stream. */
@@ -373,6 +379,7 @@ test_zero_length_reads_writes (NiceAddress *addr)
   guint8 buf[1];  /* should never be accessed */
 
   agent = nice_agent_new_reliable (NULL, NICE_COMPATIBILITY_RFC5245);
+  g_object_set (G_OBJECT (agent), "upnp", FALSE, NULL);
   nice_agent_add_local_address (agent, addr);
 
   /* Add a stream. */
