@@ -805,6 +805,24 @@ read_thread_agent_nonblocking_cb (GInputStream *input_stream,
       test_data->n_bytes);
 }
 
+static void
+wait_transmission_cb (NiceAgent *agent)
+{
+  guint stream_id;
+  gpointer tmp;
+  guint8 buffer[1024];
+  GInputVector v = { &buffer, sizeof (buffer) };
+  NiceInputMessage message = { &v, 1, NULL, 0};
+
+  tmp = g_object_get_data (G_OBJECT (agent), "stream-id");
+  stream_id = GPOINTER_TO_UINT (tmp);
+
+  /* While waiting for write thread to finish sending, keep also receiving so
+   * that any STUN messages from the peer still get processed. */
+  nice_agent_recv_messages_nonblocking (agent, stream_id, 1, &message, 1, NULL,
+      NULL);
+}
+
 static void
 write_thread_agent_nonblocking_cb (GOutputStream *output_stream,
     TestIOStreamThreadData *data)
@@ -954,7 +972,7 @@ read_thread_gsource_cb (GInputStream *input_stream,
       g_pollable_input_stream_create_source (
           G_POLLABLE_INPUT_STREAM (input_stream), NULL);
 
-  g_source_set_callback (stream_source, (GSourceFunc) read_stream_cb,
+  g_source_set_callback (stream_source, G_SOURCE_FUNC (read_stream_cb),
       &gsource_data, NULL);
   g_source_attach (stream_source, main_context);
 
@@ -1031,7 +1049,7 @@ write_thread_gsource_cb (GOutputStream *output_stream,
       g_pollable_output_stream_create_source (
           G_POLLABLE_OUTPUT_STREAM (output_stream), NULL);
 
-  g_source_set_callback (stream_source, (GSourceFunc) write_stream_cb,
+  g_source_set_callback (stream_source, G_SOURCE_FUNC (write_stream_cb),
       &gsource_data, NULL);
   g_source_attach (stream_source, main_context);
 
@@ -1105,12 +1123,12 @@ test (gboolean reliable, StreamApi stream_api, gsize n_bytes, guint n_messages,
   /* Indexed by StreamApi. */
   const TestIOStreamCallbacks callbacks[] = {
     { read_thread_agent_cb,
-      write_thread_agent_cb, NULL, NULL, },  /* STREAM_AGENT */
+      write_thread_agent_cb, NULL, NULL, wait_transmission_cb },  /* STREAM_AGENT */
     { read_thread_agent_nonblocking_cb, write_thread_agent_nonblocking_cb,
-      NULL, NULL, },  /* STREAM_AGENT_NONBLOCKING */
-    { read_thread_gio_cb, write_thread_gio_cb, NULL, NULL, },  /* STREAM_GIO */
+      NULL, NULL, wait_transmission_cb },  /* STREAM_AGENT_NONBLOCKING */
+    { read_thread_gio_cb, write_thread_gio_cb, NULL, NULL, NULL},  /* STREAM_GIO */
     { read_thread_gsource_cb, write_thread_gsource_cb,
-      NULL, NULL },  /* STREAM_GSOURCE */
+      NULL, NULL, NULL },  /* STREAM_GSOURCE */
   };
 
   test_data_init (&l_data, reliable, stream_api, n_bytes, n_messages,
@@ -1138,7 +1156,7 @@ guint32 option_transmit_seed = 0;
 guint32 option_receive_seed = 0;
 gsize option_n_bytes = 10000;
 guint option_n_messages = 50;
-guint option_timeout = 1200;  /* seconds */
+guint option_timeout = 15;  /* seconds */
 gboolean option_long_mode = FALSE;
 
 static GOptionEntry entries[] = {
@@ -1151,7 +1169,7 @@ static GOptionEntry entries[] = {
   { "n-messages", 'm', 0, G_OPTION_ARG_INT64, &option_n_messages,
     "Number of messages to send in each test (default 50)", "M" },
   { "timeout", 't', 0, G_OPTION_ARG_INT, &option_timeout,
-    "Deadlock detection timeout length, in seconds (default: 1200)", "S" },
+    "Deadlock detection timeout length, in seconds (default: 15)", "S" },
   { "long-mode", 'l', 0, G_OPTION_ARG_NONE, &option_long_mode,
     "Enable all tests, rather than a fast subset", NULL },
   { NULL },
@@ -1202,8 +1220,6 @@ main (int argc, char *argv[])
   WSADATA w;
   WSAStartup (0x0202, &w);
 #endif
-  g_type_init ();
-  g_thread_init (NULL);
 
   if (!long_mode) {
     /* Quick mode. Just test each of the stream APIs in reliable and
